==> pointpos_api-0.0.16.tar.gz: lib/model/order.dart <==
import 'package:jaguar_serializer/jaguar_serializer.dart';


import 'package:pointpos_api/model/order_sent_receipts.dart';

import 'package:pointpos_api/model/order_payments.dart';

import 'package:pointpos_api/model/order_items.dart';

part 'order.jser.dart';

class Order {
  
  @Alias('id', isNullable: false,  )
  final String id;
  
  @Alias('merchantId', isNullable: false,  )
  final String merchantId;
  
  @Alias('outletId', isNullable: false,  )
  final String outletId;
  
  @Alias('items', isNullable: false,  )
  final List<OrderItems> items;
  
  @Alias('discount', isNullable: false,  )
  final num discount;
  
  @Alias('subTotal', isNullable: false,  )
  final num subTotal;
  
  @Alias('customerId', isNullable: false,  )
  final String customerId;
  
  @Alias('payments', isNullable: false,  )
  final List<OrderPayments> payments;
  
  @Alias('sentReceipts', isNullable: false,  )
  final List<OrderSentReceipts> sentReceipts;
  
  @Alias('createdAt', isNullable: false,  )
  final String createdAt;
  
  @Alias('createdBy', isNullable: false,  )
  final String createdBy;
  
  @Alias('updatedAt', isNullable: false,  )
  final String updatedAt;
  
  @Alias('updatedBy', isNullable: false,  )
  final String updatedBy;
  

  Order(
      

{
     this.id = null,  
     this.merchantId = null,  
     this.outletId = null,  
    
     this.items = const [],   this.discount = null,  
     this.subTotal = null,  
     this.customerId = null,  
    
     this.payments = const [],  
     this.sentReceipts = const [],   this.createdAt = null,  
     this.createdBy = null,  
     this.updatedAt = null,  
     this.updatedBy = null 
    
    }
  );

  @override
  String toString() {
    return 'Order[id=$id, merchantId=$merchantId, outletId=$outletId, items=$items, discount=$discount, subTotal=$subTotal, customerId=$customerId, payments=$payments, sentReceipts=$sentReceipts, createdAt=$createdAt, createdBy=$createdBy, updatedAt=$updatedAt, updatedBy=$updatedBy, ]';
  }
}

@GenSerializer(nullableFields: true)
class OrderSerializer extends Serializer<Order> with _$OrderSerializer {

}

==> pointpos_api-0.2.0.tar.gz: lib/model/order.dart <==
import 'package:jaguar_serializer/jaguar_serializer.dart';


import 'package:pointpos_api/model/order_sent_receipts.dart';

import 'package:pointpos_api/model/order_payments.dart';

import 'package:pointpos_api/model/order_items.dart';

part 'order.jser.dart';

class Order {
  
  @Alias('id', isNullable: false,  )
  final String id;
  
  @Alias('merchantId', isNullable: false,  )
  final String merchantId;
  
  @Alias('outletId', isNullable: false,  )
  final String outletId;
  
  @Alias('items', isNullable: false,  )
  final List<OrderItems> items;
  
  @Alias('discount', isNullable: false,  )
  final num discount;
  
  @Alias('subTotal', isNullable: false,  )
  final num subTotal;
  
  @Alias('customerId', isNullable: false,  )
  final String customerId;
  
  @Alias('payments', isNullable: false,  )
  final List<OrderPayments> payments;
  
  @Alias('sentReceipts', isNullable: false,  )
  final List<OrderSentReceipts> sentReceipts;
  
  @Alias('createdAt', isNullable: false,  )
  final String createdAt;
  
  @Alias('createdBy', isNullable: false,  )
  final String createdBy;
  
  @Alias('updatedAt', isNullable: false,  )
  final String updatedAt;
  
  @Alias('updatedBy', isNullable: false,  )
  final String updatedBy;
  
  @Alias('deleted', isNullable: false,  )
  final bool deleted;
  

  Order(
      

{
     this.id = null,  
     this.merchantId = null,  
     this.outletId = null,  
    
     this.items = const [],   this.discount = null,  
     this.subTotal = null,  
     this.customerId = null,  
    
     this.payments = const [],  
     this.sentReceipts = const [],   this.createdAt = null,  
     this.createdBy = null,  
     this.updatedAt = null,  
     this.updatedBy = null,  
     this.deleted = null 
    
    }
  );

  @override
  String toString() {
    return 'Order[id=$id, merchantId=$merchantId, outletId=$outletId, items=$items, discount=$discount, subTotal=$subTotal, customerId=$customerId, payments=$payments, sentReceipts=$sentReceipts, createdAt=$createdAt, createdBy=$createdBy, updatedAt=$updatedAt, updatedBy=$updatedBy, deleted=$deleted, ]';
  }
}

@GenSerializer(nullableFields: true)
class OrderSerializer extends Serializer<Order> with _$OrderSerializer {

}
